/*
# $BEGIN_SYNCGENIE_LICENSE$
# 
# This file is part of the SyncGenie project, a library for the Arduino IDE
# for interfacing with the the Teensy microcontroller via a SyncGenie
# breakout board (see https://osf.io/r9pb6/ ), with an emphasis on time
# synchronization in neuroscience experiments.
# 
# Author: Jeremy Hill (2024-)
# 
# No Copyright
# ============
# The author has dedicated this work to the public domain under the terms of
# Creative Commons' CC0 1.0 Universal legal code, waiving all of his rights to
# the work worldwide under copyright law, including all related and neighboring
# rights, to the extent allowed by law.
# 
# You can copy, modify, distribute and perform the work, even for commercial
# purposes, all without asking permission. See Other Information below.
# 
# Other Information
# =================
# In no way are the patent or trademark rights of any person affected by CC0,
# nor are the rights that other persons may have in the work or in how the work
# is used, such as publicity or privacy rights.
# 
# The author makes no warranties about the work, and disclaims liability for
# all uses of the work, to the fullest extent permitted by applicable law. When
# using or citing the work, you are requested to preserve the author attribution
# and this copyright waiver, but you should not imply endorsement by the author.
# 
# $END_SYNCGENIE_LICENSE$
*/

#ifndef   __SerialTriggerOutput_CPP__
#define   __SerialTriggerOutput_CPP__

#include "SerialTriggerOutput.h"

SerialTriggerOutput::SerialTriggerOutput( HardwareSerial & serialPort, int baud )
: port( serialPort ), mComposed( 0 ), mSent( 0 )
{
	this->begin( baud ); 
}

SerialTriggerOutput::~SerialTriggerOutput()
{
	
}

void
SerialTriggerOutput::begin( int baud )
{
	if( !baud ) return;
	this->port.begin( baud ); 
	while( !this->port ) { }
}

void
SerialTriggerOutput::end( void )
{
	this->port.end();
}

void
SerialTriggerOutput::reset( uint8_t value )
{
	mComposed = value;
}

bool
SerialTriggerOutput::setBit( unsigned int bitPosition, bool value )
{
	if( bitPosition > 7 ) return value;
	uint8_t mask = 1 << bitPosition;
	if( value ) mComposed |=  mask;
	else        mComposed &= ~mask;
	return value;
}

bool
SerialTriggerOutput::send( bool evenIfZero )
{
	if( mComposed == mSent ) return false;
	mSent = mComposed;
	if( mComposed == 0 && !evenIfZero ) return false;
	this->port.write( mComposed );
	this->port.flush();
	if( this->debug.length() ) { Serial.print( this->debug ); Serial.print( ": " ); Serial.println( ( int ) mComposed ); Serial.flush(); }
	return true;
}

#endif // __SerialTriggerOutput_CPP__
