/*
# $BEGIN_SYNCGENIE_LICENSE$
# 
# This file is part of the SyncGenie project, a library for the Arduino IDE
# for interfacing with the the Teensy microcontroller via a SyncGenie
# breakout board (see https://osf.io/r9pb6/ ), with an emphasis on time
# synchronization in neuroscience experiments.
# 
# Author: Jeremy Hill (2024-)
# 
# No Copyright
# ============
# The author has dedicated this work to the public domain under the terms of
# Creative Commons' CC0 1.0 Universal legal code, waiving all of his rights to
# the work worldwide under copyright law, including all related and neighboring
# rights, to the extent allowed by law.
# 
# You can copy, modify, distribute and perform the work, even for commercial
# purposes, all without asking permission. See Other Information below.
# 
# Other Information
# =================
# In no way are the patent or trademark rights of any person affected by CC0,
# nor are the rights that other persons may have in the work or in how the work
# is used, such as publicity or privacy rights.
# 
# The author makes no warranties about the work, and disclaims liability for
# all uses of the work, to the fullest extent permitted by applicable law. When
# using or citing the work, you are requested to preserve the author attribution
# and this copyright waiver, but you should not imply endorsement by the author.
# 
# $END_SYNCGENIE_LICENSE$
*/

#ifndef   __SyncGeniePins_H__
#define   __SyncGeniePins_H__

#include "SyncGenieTeensyVersioning.h"

static const int BOARD_REVISION = 2;
// The SyncGenie Revision 2 is the new name for TriggerBoxV2, a.k.a. the Ortiz Box.
// Three boxes were made, all hard-wired with Teensy 3.2
#ifndef ARDUINO_TEENSY32
#	error    If SYNCGENIE_BOARD_REVISION is 2, board "Teensy 3.2/3.1" should be selected.
#endif
static const int D0_OUT    = 8;
static const int D1_OUT    = 0;
static const int D2_OUT    = 1;
static const int D3_OUT    = 2;
static const int D4_OUT    = 3;
static const int D5_OUT    = 4;
static const int D6_OUT    = 5;
static const int D7_OUT    = 6;

static const int D8_LED    = 7;
static const int D9_LED    = 13;

static const int D0_IN     = 14;
static const int D1_IN     = 15;
static const int D2_IN     = 16;
static const int D3_IN     = 17;
static const int D4_IN     = 18;
static const int D5_IN     = 19;
static const int D6_IN     = 20;
static const int D7_IN     = 21;

static const int RJ45_PIN1 = 12; // put this into INPUT_PULLUP mode; pins 7 and 8 are wired to ground
static const int RJ45_PIN2 = 11; // put this into INPUT_PULLUP mode; pins 7 and 8 are wired to ground

static const int SELECTOR_BUTTON = -1;
static const int SELECTOR_A      = -1;
static const int SELECTOR_B      = -1;
static const int BUTTON          = -1;
static const int BNC1            = 30; //  left when the bargraph LEDs are on top
static const int BNC2            = 27; // right when the bargraph LEDs are on top
static const int POT1            = 29; //  left when the TRS and RJ45 connectors are towards you
static const int POT2            = 31; // right when the TRS and RJ45 connectors are towards you
static const int JST_PIN1        = -1;
static const int JST_PIN2        = -1;
static const int TRS1_TIP        = 36; //    top TRS connector when bargraph LEDs are on top (not PWM capable)
static const int TRS1_RING       = 37; //    top TRS connector when bargraph LEDs are on top (not PWM capable)
static const int TRS2_TIP        = 22; // bottom TRS connector when bargraph LEDs are on top (PWM capable)
static const int TRS2_RING       = 23; // bottom TRS connector when bargraph LEDs are on top (PWM capable)
static const int TRS3_TIP        = -1;
static const int TRS3_RING       = -1;
static const int TRS4_TIP        = -1;
static const int TRS4_RING       = -1;
static const int LCD_RS          = -1;
static const int LCD_EN          = -1;
static const int LCD_D4          = -1;
static const int LCD_D5          = -1;
static const int LCD_D6          = -1;
static const int LCD_D7          = -1;

#ifdef __FakeLiquidCrystal_H__
	static const int LCD_COLS        = 16;
	static const int LCD_ROWS        =  2;
#else
	static const int LCD_COLS        = -1;
	static const int LCD_ROWS        = -1;
#endif

#endif // __SyncGeniePins_H__
